@@ -1,4 +1,5 @@
 import difflib
+import platform
 import re
 from collections import OrderedDict
 
@@ -86,8 +87,9 @@ class ExceptionHandlingGroup(click.Group):
             Py42TrustedActivityInvalidCharacterError,
             Py42TrustedActivityIdNotFound,
         ) as err:
-            self.logger.log_error(err)
-            raise Code42CLIError(str(err))
+            msg = err.args[0]
+            self.logger.log_error(msg)
+            raise Code42CLIError(msg)
 
         except Py42ForbiddenError as err:
             self.logger.log_verbose_error(self._original_args, err.response.request)
@@ -100,6 +102,15 @@ class ExceptionHandlingGroup(click.Group):
             self.logger.log_verbose_error(self._original_args, err.response.request)
             raise LoggedCLIError("Problem making request to server.")
 
+        except UnicodeEncodeError:
+            if platform.system() == "Windows":
+                cmd = 'if using powershell: $ENV:PYTHONIOENCODING="utf-16"\nif using cmd.exe:    SET PYTHONIOENCODING="utf-16"'
+            else:
+                cmd = 'export PYTHONIOENCODING="utf-8"'
+            raise Code42CLIError(
+                f"Failed to handle unicode character using environment's detected encoding, try running the following:\n\n{cmd}\n\nand then re-run your `code42` command."
+            )
+
         except OSError:
             raise
 
